<?php
// Include the database connection file
include '../../includes/connection.php';

// Check if the request method is POST
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Retrieve the email and other fields from the POST request
    $email = $_POST['email'];
    $sender_name = $_POST['sender_name'];
    $subject = $_POST['subject'];
    $message = $_POST['message'];

    // Check if required fields are provided
    if (empty($email) || empty($sender_name) || empty($subject) || empty($message)) {
        echo json_encode(["status" => "error", "message" => "Email, sender name, subject, and message are required."]);
        exit();
    }

    // Check if the email exists in the database
    $sql = "SELECT * FROM Users WHERE email = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        // Email exists, visit the external URL
        $url = 'https://deentime.app/mail/send.php';
        $url .= '?' . http_build_query([
            'sender_name' => $sender_name,
            'subject' => $subject,
            'receiver_email' => $email,
            'message' => $message
        ]);

        // Initialize cURL
        $ch = curl_init($url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); // Disable SSL verification for testing

        // Execute cURL request
        $response = curl_exec($ch);
        $http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);

        // Log response for debugging
        error_log("Response: " . $response);
        error_log("HTTP Code: " . $http_code);

        // Check if the response is valid JSON
        $responseData = json_decode($response, true);

        if (json_last_error() !== JSON_ERROR_NONE) {
            error_log("JSON Decode Error: " . json_last_error_msg());
            echo json_encode(["status" => "error", "message" => "Failed to decode JSON response. Response: " . $response]);
        } else {
            // Check if the response indicates success
            if ($http_code == 200 && isset($responseData['success']) && $responseData['success']) {
                echo json_encode(["status" => "success", "message" => "Email validated and message sent successfully."]);
            } else {
                echo json_encode(["status" => "error", "message" => "Failed to send the message. Response: " . $response]);
            }
        }
    } else {
        // Email does not exist
        echo json_encode(["status" => "error", "message" => "Email not found."]);
    }

    // Close the statement and the connection
    $stmt->close();
    $conn->close();
} else {
    // Invalid request method
    echo json_encode(["status" => "error", "message" => "Invalid request method."]);
}
?>
