<?php
// Database connection parameters
$host = 'localhost'; // Replace with your database host
$dbname = 'takemeeasy_signalapp'; // Replace with your database name
$username = 'takemeeasy_signalapp'; // Replace with your database username
$password = 'takemeeasy_signalapp'; // Replace with your database password

// Create a new database connection
$db = new mysqli($host, $username, $password, $dbname);

// Check if the connection is successful
if ($db->connect_error) {
    file_put_contents('error_log.txt', "Connection failed: " . $db->connect_error . "\n", FILE_APPEND);
    die("Connection failed. Please try again later.");
}
file_put_contents('debug_log.txt', "Database connected successfully.\n", FILE_APPEND);

// Log the received data for debugging
file_put_contents('ipn_log.txt', "Received POST data:\n" . print_r($_POST, true) . "\n", FILE_APPEND);

// Retrieve POST data
$txn_id = isset($_POST['txn_id']) ? $_POST['txn_id'] : '';
$amount1 = isset($_POST['amount1']) ? $_POST['amount1'] : '0';
$status = isset($_POST['status']) ? $_POST['status'] : '';
$buyer_email = isset($_POST['email']) ? $_POST['email'] : '';
$currency1 = isset($_POST['currency1']) ? $_POST['currency1'] : 'USD'; // Default currency if not provided

// Check for status 100
if ($status != '100') {
    file_put_contents('error_log.txt', "Transaction status is not 100, ignoring.\n", FILE_APPEND);
    die("Transaction status is not 100, ignoring.");
}

// Check if amount1 matches with a plan in the Plans table
$amount_check_query = $db->prepare("SELECT plan_name, duration_days FROM Plans WHERE price = ? AND plan_status = 'Active'");
if (!$amount_check_query) {
    file_put_contents('error_log.txt', "Database prepare error (amount_check_query): " . $db->error . "\n", FILE_APPEND);
    die("Database prepare error.");
}
$amount_check_query->bind_param('d', $amount1);
$amount_check_query->execute();
$amount_check_query->bind_result($plan_name, $plan_duration);
$amount_check_query->fetch();
$amount_check_query->close();

if (!$plan_name) {
    file_put_contents('error_log.txt', "No matching plan found for amount $amount1.\n", FILE_APPEND);
    die("No matching plan found.");
}

// Calculate the purchase and expired dates
$purchase_date = date('Y-m-d'); // Current date in yyyy-mm-dd format
$purchase_date_timestamp = strtotime($purchase_date);
$expired_date_timestamp = strtotime("+$plan_duration days", $purchase_date_timestamp);
$expired_date = date('Y-m-d', $expired_date_timestamp);

// Check if the buyer email exists in the Users table
$email_check_query = $db->prepare("SELECT id FROM Users WHERE email = ?");
if (!$email_check_query) {
    file_put_contents('error_log.txt', "Database prepare error (email_check_query): " . $db->error . "\n", FILE_APPEND);
    die("Database prepare error.");
}
$email_check_query->bind_param('s', $buyer_email);
$email_check_query->execute();
$email_check_query->bind_result($user_id);
$email_check_query->fetch();
$email_check_query->close();

if ($user_id) {
    // Update the Users table
    $update_user_query = $db->prepare("UPDATE Users SET user_type = ?, plan_duration = ?, purchase_date = ?, expired_date = ? WHERE id = ?");
    if (!$update_user_query) {
        file_put_contents('error_log.txt', "Database prepare error (update_user_query): " . $db->error . "\n", FILE_APPEND);
        die("Database prepare error.");
    }
    $update_user_query->bind_param('ssssi', $plan_name, $plan_duration, $purchase_date, $expired_date, $user_id);
    
    if (!$update_user_query->execute()) {
        file_put_contents('error_log.txt', "Failed to update user data: " . $update_user_query->error . "\n", FILE_APPEND);
    }
    $update_user_query->close();
    file_put_contents('debug_log.txt', "User data updated successfully.\n", FILE_APPEND);
}

// Insert the transaction data into TransactionsHistory table
$stmt = $db->prepare("INSERT INTO TransactionsHistory (txn_id, buyer_email, amount1, currency1, status, plan_name, plan_duration, purchase_date, expired_date, created_at) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, NOW())");
if (!$stmt) {
    file_put_contents('error_log.txt', "Database prepare error (insert_transaction_query): " . $db->error . "\n", FILE_APPEND);
    die("Database prepare error.");
    
}
$stmt->bind_param('sssssssss', $txn_id, $buyer_email, $amount1, $currency1, $status, $plan_name, $plan_duration, $purchase_date, $expired_date);

if ($stmt->execute()) {
    file_put_contents('debug_log.txt', "Payment data stored successfully.\n", FILE_APPEND);
    echo "Payment data stored successfully.";
    // Prepare data for the cURL request
    $api_url = 'https://deentime.app/mail/send.php';
    $sender_name = 'Signifx';
    $subject = 'Payment Confirmation';
    $receiver_email = $buyer_email;
    $message = "Dear Customer,\n\nYour payment has been successfully confirmed. Your Subscription, '$plan_name', has been activated and is now ready for you to use.\n\nThank you for your purchase!";

    // cURL request
    $ch = curl_init();

    curl_setopt($ch, CURLOPT_URL, $api_url . '?' . http_build_query([
        'sender_name' => $sender_name,
        'subject' => $subject,
        'receiver_email' => $receiver_email,
        'message' => $message
    ]));
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

    // Execute cURL request
    $response = curl_exec($ch);
    $http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE); // Get HTTP response code

    // Log the response for debugging
    file_put_contents('debug_log.txt', "cURL response: " . $response . "\n", FILE_APPEND);
    file_put_contents('debug_log.txt', "HTTP code: " . $http_code . "\n", FILE_APPEND);

    if (curl_errno($ch)) {
        file_put_contents('error_log.txt', "cURL error: " . curl_error($ch) . "\n", FILE_APPEND);
    } elseif ($http_code >= 200 && $http_code < 300) {
        file_put_contents('debug_log.txt', "cURL request sent successfully.\n", FILE_APPEND);
    } else {
        file_put_contents('error_log.txt', "HTTP error code: " . $http_code . "\n", FILE_APPEND);
    }

    curl_close($ch);
} else {
    file_put_contents('error_log.txt', "Failed to store payment data: " . $stmt->error . "\n", FILE_APPEND);
}
$stmt->close();

// Close the database connection
$db->close();
file_put_contents('debug_log.txt', "Database connection closed.\n", FILE_APPEND);
?>
